@@ -1,9 +1,11 @@
 import os
-import time
-from copy import deepcopy
+from abc import ABC, abstractmethod
 from typing import List, Optional, Union, Literal
 
 import json5
+from openai import OpenAI, AsyncOpenAI
+from openai.types.chat import ChatCompletionToolParam
+
 from duowen_agent.error import LLMError, LengthLimitExceededError, MaxTokenExceededError
 from duowen_agent.llm.entity import (
     MessagesSet,
@@ -15,16 +17,34 @@ from duowen_agent.tools.base import BaseTool
 from duowen_agent.utils.core_utils import (
     record_time,
     async_record_time,
-    stream_to_string,
-    remove_think,
 )
-from openai import OpenAI, AsyncOpenAI
-from openai.types.chat import ChatCompletionToolParam
-
 from .entity import ToolsCall, Tool
 
 
-class OpenAIChat:
+class BaseAIChat(ABC):
+    base_url: str
+    api_key: Optional[str]
+    model: str
+    token_limit: int
+
+    @abstractmethod
+    def chat_for_stream(
+        self,
+        messages: str | List[dict] | List[Message] | MessagesSet,
+        **kwargs,
+    ):
+        raise NotImplementedError
+
+    @abstractmethod
+    def chat(
+        self,
+        messages: str | List[dict] | List[Message] | MessagesSet,
+        **kwargs,
+    ):
+        raise NotImplementedError
+
+
+class OpenAIChat(BaseAIChat):
     def __init__(
         self,
         base_url: str = None,
@@ -525,103 +545,3 @@ class OpenAIChat:
 
         except Exception as e:
             raise LLMError(str(e), self.base_url, self.model, messages)
-
-
-def continue_chat(
-    llm: OpenAIChat,
-    messages: str | List[dict] | List[Message] | MessagesSet,
-    continue_cnt: int = 3,
-    **kwargs,
-) -> str:
-    full_response = ""  # 存储所有轮次完整响应
-    ori_msg = format_messages(messages)
-    msg = deepcopy(ori_msg)
-
-    for attempt in range(continue_cnt):
-        buffer = ""
-        try:
-            # 流式获取当前轮次响应
-            for chunk in llm.chat_for_stream(msg, **kwargs):
-                buffer += chunk
-
-            # 成功完成：累积并返回
-            full_response += remove_think(buffer)
-            return full_response
-
-        except LengthLimitExceededError as e:
-            if attempt == continue_cnt - 1:  # 最后一次尝试仍失败
-                # print("-" * 50)
-                # print(msg.get_format_messages())
-                # print("-" * 50)
-                raise e
-
-            # 处理当前部分响应
-            current_part = remove_think(buffer)
-            full_response += current_part  # 累积到完整响应
-            msg = deepcopy(ori_msg)
-            # 更新消息历史
-            msg.add_assistant(full_response)  # 包含所有历史内容
-            msg.add_user("continue")
-
-    return full_response  # 理论上不会执行到这里
-
-
-async def async_continue_chat(
-    llm: OpenAIChat,
-    messages: str | List[dict] | List[Message] | MessagesSet,
-    continue_cnt: int = 3,
-    **kwargs,
-) -> str:
-    full_response = ""  # 存储所有轮次完整响应
-    ori_msg = format_messages(messages)
-    msg = deepcopy(ori_msg)
-
-    for attempt in range(continue_cnt):
-        buffer = ""
-        try:
-            # 流式获取当前轮次响应
-            async for chunk in llm.achat_for_stream(msg, **kwargs):
-                buffer += chunk
-
-            # 成功完成：累积并返回
-            full_response += remove_think(buffer)
-            return full_response
-
-        except LengthLimitExceededError as e:
-            if attempt == continue_cnt - 1:  # 最后一次尝试仍失败
-                # print("-" * 50)
-                # print(msg.get_format_messages())
-                # print("-" * 50)
-                raise LengthLimitExceededError(content=buffer)
-
-            # 处理当前部分响应
-            current_part = remove_think(buffer)
-            full_response += current_part  # 累积到完整响应
-            msg = deepcopy(ori_msg)
-            # 更新消息历史
-            msg.add_assistant(full_response)  # 包含所有历史内容
-            msg.add_user("continue")
-
-    return full_response
-
-
-def retry_chat(
-    llm: OpenAIChat,
-    messages: str | List[dict] | List[Message] | MessagesSet,
-    stream: bool = True,
-    retry_times: int = 3,
-    sleep_time: int = 5,
-    **kwargs,
-) -> str:
-    for i in range(retry_times):
-        try:
-            if stream:
-                res = stream_to_string(llm.chat_for_stream(messages, **kwargs))
-                return res
-            else:
-                return llm.chat(messages, **kwargs)
-        except LLMError as e:
-            if i == retry_times - 1:
-                raise e
-            else:
-                time.sleep(sleep_time)
