@@ -10,10 +10,11 @@ from hashlib import md5
 from typing import Any, Union, List
 
 import networkx as nx
-from duowen_agent.llm import tokenizer
 from networkx.readwrite import json_graph
 from pyvis.network import Network
 
+from duowen_agent.llm import tokenizer
+
 
 def create_file_dir(file_name):
     dir_name = os.path.dirname(file_name)
@@ -336,7 +337,6 @@ class NetworkXUtils:
         self,
         start_node: str,
         steps: int,
-        top_k_node: int = 100,  # 使用pagerank\rank判断
         top_k_neighbors: int = 100,  # 使用weight判断
         filter_entities: List[str] = None,
     ) -> nx.Graph:
@@ -386,9 +386,7 @@ class NetworkXUtils:
             #     reverse=True,
             # )[:top_k_node]
 
-            sorted_neighbors = neighbors[:top_k_node]
-
-            for neighbor in sorted_neighbors:
+            for neighbor in neighbors:
                 edge_data = self.get_edge(current_node, neighbor)
                 node_data = self.get_node(neighbor)
 
