@@ -31,10 +31,14 @@ class HumanFeedBackTool(BaseTool):
     def __init__(
         self,
         output_func: Callable[[str], None] = _print_func,
-        input_func: Callable = input,
+        input_func: Callable[[], str] = lambda: input("input> "),
         *args,
         **kwargs,
     ):
+        """
+        :param output_func: 发送反馈内容给用户
+        :param input_func: 获取人类反馈的结果
+        """
         super().__init__(*args, **kwargs)
         self.output_func = output_func
         self.input_func = input_func
